l = []
l.append(l)
r = []
r = l
snuif
friet()

class muf:
    def __init__(self):
        a = self.hoppa
        l = [a]
        l[0]()
    def hoppa(self):
        print 'hoppa'

muf()

class M(object):
    pass
class P2(M):
    def handle_key_press(self, n):
        pass
class P1(M):
    pass

p = P1()
p = P2()
p.handle_key_press("X")

#*WARNING* 7.py: variable 'l' has dynamic (sub)type
#*WARNING* 7.py: variable 'r' has dynamic (sub)type
#*WARNING* 7.py:5: variable 'snuif' has no type
#*WARNING* 7.py:6: unresolved call to 'friet'
#*WARNING* 7.py:12: unresolved call (possibly caused by method passing, which is currently not allowed)
#*WARNING* 7.py:28: class 'P1' has no method 'handle_key_press'
